==> okio-jvm-3.6.0-javadoc.jar: okio/okio/-file-system/-companion/index.md <==
//[okio](../../../../index.md)/[okio](../../index.md)/[FileSystem](../index.md)/[Companion](index.md)

# Companion

[common]\
expect object [Companion](index.md)

[js, jvm, native, wasm]\
actual object [Companion](index.md)

## Properties

| Name | Summary |
|---|---|
| [RESOURCES](-r-e-s-o-u-r-c-e-s.md) | [jvm]<br>@[JvmField](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.jvm/-jvm-field/index.html)<br>val [RESOURCES](-r-e-s-o-u-r-c-e-s.md): [FileSystem](../index.md)<br>A read-only file system holding the classpath resources of the current process. If a resource is available with [ClassLoader.getResource](https://docs.oracle.com/javase/8/docs/api/java/lang/ClassLoader.html#getResource-kotlin.String-), it is also available via this file system. |
| SYSTEM | [jvm, native]<br>[jvm]<br>@[JvmField](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.jvm/-jvm-field/index.html)<br>val [SYSTEM]([jvm]-s-y-s-t-e-m.md): [FileSystem](../index.md)<br>[native]<br>val [SYSTEM]([native]-s-y-s-t-e-m.md): [FileSystem](../index.md)<br>The current process's host file system. Use this instance directly, or dependency inject a [FileSystem](../index.md) to make code testable. |
| [SYSTEM_TEMPORARY_DIRECTORY](-s-y-s-t-e-m_-t-e-m-p-o-r-a-r-y_-d-i-r-e-c-t-o-r-y.md) | [common]<br>expect val [SYSTEM_TEMPORARY_DIRECTORY](-s-y-s-t-e-m_-t-e-m-p-o-r-a-r-y_-d-i-r-e-c-t-o-r-y.md): [Path](../../-path/index.md)<br>Returns a writable temporary directory on SYSTEM.<br>[js, jvm, native, wasm]<br>[js, native, wasm]<br>actual val [SYSTEM_TEMPORARY_DIRECTORY](-s-y-s-t-e-m_-t-e-m-p-o-r-a-r-y_-d-i-r-e-c-t-o-r-y.md): [Path](../../-path/index.md)<br>[jvm]<br>@[JvmField](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.jvm/-jvm-field/index.html)<br>actual val [SYSTEM_TEMPORARY_DIRECTORY](-s-y-s-t-e-m_-t-e-m-p-o-r-a-r-y_-d-i-r-e-c-t-o-r-y.md): [Path](../../-path/index.md) |

## Functions

| Name | Summary |
|---|---|
| [asOkioFileSystem](as-okio-file-system.md) | [jvm]<br>@[JvmName](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.jvm/-jvm-name/index.html)(name = &quot;get&quot;)<br>@[JvmStatic](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.jvm/-jvm-static/index.html)<br>fun [FileSystem](https://docs.oracle.com/javase/8/docs/api/java/nio/file/FileSystem.html).[asOkioFileSystem](as-okio-file-system.md)(): [FileSystem](../index.md) |

==> okio-jvm-3.9.1-javadoc.jar: okio/okio/-file-system/-companion/index.md <==
//[okio](../../../../index.md)/[okio](../../index.md)/[FileSystem](../index.md)/[Companion](index.md)

# Companion

[common]\
expect object [Companion](index.md)

[js, jvm, native, wasm]\
actual object [Companion](index.md)

## Properties

| Name | Summary |
|---|---|
| [RESOURCES](-r-e-s-o-u-r-c-e-s.md) | [jvm]<br>@[JvmField](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.jvm/-jvm-field/index.html)<br>val [RESOURCES](-r-e-s-o-u-r-c-e-s.md): [FileSystem](../index.md)<br>A read-only file system holding the classpath resources of the current process. If a resource is available with [ClassLoader.getResource](https://docs.oracle.com/javase/8/docs/api/java/lang/ClassLoader.html#getResource-kotlin.String-), it is also available via this file system. |
| SYSTEM | [jvm, native]<br>[jvm]<br>@[JvmField](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.jvm/-jvm-field/index.html)<br>val [SYSTEM]([jvm]-s-y-s-t-e-m.md): [FileSystem](../index.md)<br>[native]<br>val [SYSTEM]([native]-s-y-s-t-e-m.md): [FileSystem](../index.md)<br>The current process's host file system. Use this instance directly, or dependency inject a [FileSystem](../index.md) to make code testable. |
| [SYSTEM](../../-s-y-s-t-e-m.md) | [systemFileSystem]<br>expect val [FileSystem.Companion](index.md#1539401563%2FMain%2F535390985).[SYSTEM](../../-s-y-s-t-e-m.md): FileSystem |
| [SYSTEM_TEMPORARY_DIRECTORY](-s-y-s-t-e-m_-t-e-m-p-o-r-a-r-y_-d-i-r-e-c-t-o-r-y.md) | [common]<br>expect val [SYSTEM_TEMPORARY_DIRECTORY](-s-y-s-t-e-m_-t-e-m-p-o-r-a-r-y_-d-i-r-e-c-t-o-r-y.md): [Path](../../-path/index.md)<br>Returns a writable temporary directory on SYSTEM.<br>[js, jvm, native, wasm]<br>[js, native, wasm]<br>actual val [SYSTEM_TEMPORARY_DIRECTORY](-s-y-s-t-e-m_-t-e-m-p-o-r-a-r-y_-d-i-r-e-c-t-o-r-y.md): [Path](../../-path/index.md)<br>[jvm]<br>@[JvmField](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.jvm/-jvm-field/index.html)<br>actual val [SYSTEM_TEMPORARY_DIRECTORY](-s-y-s-t-e-m_-t-e-m-p-o-r-a-r-y_-d-i-r-e-c-t-o-r-y.md): [Path](../../-path/index.md) |

## Functions

| Name | Summary |
|---|---|
| [asOkioFileSystem](as-okio-file-system.md) | [jvm]<br>@[JvmName](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.jvm/-jvm-name/index.html)(name = &quot;get&quot;)<br>@[JvmStatic](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.jvm/-jvm-static/index.html)<br>fun [FileSystem](https://docs.oracle.com/javase/8/docs/api/java/nio/file/FileSystem.html).[asOkioFileSystem](as-okio-file-system.md)(): [FileSystem](../index.md) |
